package
Version:
v1.13.2
Opens a new window with list of versions in this module.
Published: Aug 7, 2025
License: Apache-2.0
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Action struct {
Name string `json:"name"`
Roles []ARole `json:"roles"`
}
type Scope struct {
Name rbac.Scope `json:"name"`
Actions []rbac.Verb `json:"actions"`
}
type View struct {
Roles []Role `json:"roles"`
Actions []Action `json:"actions"`
Scopes []Scope `json:"scopes"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.